@@ -428,7 +428,7 @@ static Bool i830_xf86crtc_resize(ScrnInfoPtr scrn, int width, int height)
 		xf86DrvMsg(scrn->scrnIndex, X_INFO,
 			   "Allocate new frame buffer %dx%d stride %d\n", width,
 			   height, scrn->displayWidth);
-		I830Sync(scrn);
+		intel_sync(scrn);
 		i830WaitForVblank(scrn);
 		new_front = i830_allocate_framebuffer(scrn);
 		if (!new_front) {
@@ -456,7 +456,7 @@ static Bool i830_xf86crtc_resize(ScrnInfoPtr scrn, int width, int height)
 			   "New front buffer at 0x%lx\n",
 			   intel->front_buffer->offset);
 		i830_set_new_crtc_bo(scrn);
-		I830Sync(scrn);
+		intel_sync(scrn);
 		i830WaitForVblank(scrn);
 		i830_free_memory(scrn, old_front);
 	}
@@ -985,22 +985,20 @@ I830BlockHandler(int i, pointer blockData, pointer pTimeout, pointer pReadmask)
 	screen->BlockHandler = I830BlockHandler;
 
 	if (scrn->vtSema) {
-		Bool flush = FALSE;
-
 		/* Emit a flush of the rendering cache, or on the 965 and beyond
 		 * rendering results may not hit the framebuffer until significantly
 		 * later.
+		 *
+		 * XXX Under KMS this is only required because tfp does not have
+		 * the appropriate synchronisation points, so that outstanding updates
+		 * to the pixmap are flushed prior to use as a texture. The framebuffer
+		 * should be handled by the kernel domain management...
 		 */
-		if (intel->need_mi_flush || intel->batch_used)
-			flush = TRUE;
+		if (intel->need_mi_flush || !list_is_empty(&intel->flush_pixmaps))
+			intel_batch_emit_flush(scrn);
 
-		/* Flush the batch, so that any rendering is executed in a timely
-		 * fashion.
-		 */
-		intel_batch_flush(scrn, flush);
+		intel_batch_submit(scrn);
 		drmCommandNone(intel->drmSubFD, DRM_I915_GEM_THROTTLE);
-
-		intel->need_mi_flush = FALSE;
 	}
 
 	i830_uxa_block_handler(screen);
@@ -1462,7 +1460,7 @@ static void I830LeaveVT(int scrnIndex, int flags)
 
 	xf86_hide_cursors(scrn);
 
-	I830Sync(scrn);
+	intel_sync(scrn);
 
 	intel_batch_teardown(scrn);
 
